@@ -26,6 +26,10 @@ class Observation(TeamTVObject):
     def clock_id(self) -> str:
         return self._clock_id
 
+    @property
+    def description(self) -> str:
+        return self._description
+
     @property
     def attributes(self) -> dict:
         return self._attributes
@@ -37,4 +41,5 @@ class Observation(TeamTVObject):
         self._end_time = attributes['endTime']
         self._code = attributes['code']
         self._attributes = attributes['attributes'] or dict()
+        self._description = attributes['description']
         self._clock_id = attributes['clockId']
